pub fn read_string(path: &str) -> OpticResult<String>Expand description
Read a file as a UTF-8 string.
Errors
Returns OpticErrorKind::File if the file does not exist, is not
valid UTF-8, or permission is denied.
pub fn read_string(path: &str) -> OpticResult<String>Read a file as a UTF-8 string.
Returns OpticErrorKind::File if the file does not exist, is not
valid UTF-8, or permission is denied.