write_bytes

Function write_bytes 

pub fn write_bytes(path: &str, data: &[u8]) -> OpticResult<()>
Write raw bytes to a file, creating parent directories if needed.

Errors

Returns OpticErrorKind::File if the directory cannot be created or the file cannot be written.