pub fn write_string(path: &str, data: &str) -> OpticResult<()>Expand description
Write a UTF-8 string to a file, creating parent directories if needed.
Equivalent to write_bytes with data.as_bytes().
pub fn write_string(path: &str, data: &str) -> OpticResult<()>Write a UTF-8 string to a file, creating parent directories if needed.
Equivalent to write_bytes with data.as_bytes().